==> snapbelt-0.12.0-py2-none-any.whl: snapbelt/main.py <==
"""SNAPtoolbelt Main"""
import logging

import signal
import tornado.ioloop

import os
import sys

from arghandler import ArgumentHandler

from colorlog import ColoredFormatter

from snap_profile.profile import Profile, SerialProfile
from snap_profile.network import Network

import snapstraction.gus

import time

from .command_log import log_command

# Import subcommands
from .build import build
from .configure import config
from .flash import flash
from .help import help
from .node import node
from .mesh import mesh
from .low_level import call, send
from .updater import update
from .util import mkdir_p
from .output_formatters import FORMATS

log = logging.getLogger(__name__)

MAX_WAIT_SECONDS_BEFORE_SHUTDOWN = 2


def setup_sighandlers():  # pragma: no cover
    def sig_handler(sig, frame):  # pragma: no cover
        log.info('Caught signal: %s', sig)
        tornado.ioloop.IOLoop.instance().add_callback(shutdown)

    def shutdown():  # pragma: no cover
        log.info('Stopping IOLoop')

        log.info('Will shutdown in %s seconds ...', MAX_WAIT_SECONDS_BEFORE_SHUTDOWN)
        io_loop = tornado.ioloop.IOLoop.instance()

        deadline = time.time() + MAX_WAIT_SECONDS_BEFORE_SHUTDOWN

        def stop_loop():  # pragma: no cover
            now = time.time()
            if now < deadline and (io_loop._callbacks or io_loop._timeouts):
                io_loop.add_timeout(now + 1, stop_loop)
            else:
                io_loop.stop()
                log.info('Shutdown')

        stop_loop()

    signal.signal(signal.SIGTERM, sig_handler)
    signal.signal(signal.SIGINT, sig_handler)

# Go ahead and register handlers
setup_sighandlers()


def parse_log_level(level_str):
    """Parse a log level string into the logging.* log level. """
    loglevel = getattr(logging, level_str.upper(), None)
    if not isinstance(loglevel, int):
        raise ValueError('Invalid log level: %s' % level_str)

    return loglevel


def config_logging(level_str):
    """Set up colorized logging"""

    level = parse_log_level(level_str)

    formatter = ColoredFormatter(
        "%(asctime)-15s %(log_color)s%(levelname)-8s%(reset)s %(name)-8s %(blue)s%(message)s",
        datefmt=None,
        reset=True,
        log_colors={
            'DEBUG': 'cyan',
            'INFO': 'green',
            'WARNING': 'yellow',
            'ERROR': 'red',
            'CRITICAL': 'red'
        })

    handler = logging.StreamHandler()
    handler.setFormatter(formatter)
    handler.setLevel(level)

    root_logger = logging.getLogger('')
    root_logger.setLevel(level)

    # Remove any extraneous handlers
    map(root_logger.removeHandler, root_logger.handlers)

    root_logger.addHandler(handler)


def config_output(context):
    """Set up the context's output formatter"""
    context.output = FORMATS[context.output_format]()


def _get_profile(context):
    """Load the profile.
    # If there was no profile specified:
    #    Fall back on the default.
    #    If the fallback doesn't exist, create & save it.
    # If there was a profile specified:
    #    If it exists, use it.
    #    If it doesn't exist, ERROR.
    """

    if context.profile_name is None:
        # There was no profile specified.
        # Fall back on the default.
        context.profile_name = 'default'

        try:
            context.profile = Profile.load(context.profile_name)
        except:
            # If the default doesn't exist, create it.
            profile = SerialProfile()
            # Save the default for future expansion
            profile.save()
            context.profile = profile

    else:
        # A profile was specified.
        try:
            context.profile = Profile.load(context.profile_name)
        except:
            log.error("Could not find profile %s", context.profile_name)
            exit(1)


def _get_network(context):
    """Load the network.
    # If there was no network specified:
    #     Fall back on the default *for the current profile*.
    #     If the fallback network doesn't exist, create it.
    # If there was a network specified:
    #    If it exists, great, use it.
    #    If it doesn't exist, ERROR.
    """
    if context.network_name is None:
        log.debug("No network specified, using last known network for profile.")
        context.network_name = context.profile.network

        try:
            context.network = Network.load(context.network_name)

            # Update the last used profile
            context.profile.network = context.network.name
            context.profile.save()

        except:
            # Network not specified, and couldn't be found, create a default.
            log.debug("Unable to load network, falling back on factory default")
            # fall back on default
            net = Network()
            # Name it correctly.
            net.name = context.network_name
            # Save the default for future expansion
            net.save()
            context.network = net

    else:
        # A network was explicitly specified
        try:
            context.network = Network.load(context.network_name)

            # Update the last used profile
            context.profile.network = context.network.name
            context.profile.save()

        except:
            log.error("Could not find network %s", context.network_name)
            exit(1)


def init_configuration(context):
    """Initialize the configuration folder"""
    # If there's not already a ~/.snap folder, create it.
    # TODO: Does this need to be elsewhere on Windows?
    user_dir = os.path.expanduser(os.path.join("~", ".snap"))
    try:
        log.info("Creating User Dir %s if it doesn't already exist", user_dir)
        mkdir_p(user_dir)
    except:
        log.exception("Couldn't create user folder %s, you don't own your own home folder?!", user_dir)
        exit(1)

    _get_profile(context)
    # At this point, we've either errored out, or we have a profile.
    _get_network(context)

    context.license = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'License.dat')


def version(parser, context, args):
    """Print the version and exit"""
    from ._version import __version__
    context.output({'version': __version__})
    exit(0)


def autocomplete_path(parser, context, args):
    """Emit the path to the autocomplete script for use with eval $(snap autocomplete)"""
    context.output(os.path.abspath(os.path.join(os.path.dirname(__file__), 'bash_autocomplete_snap')))
    exit(0)


def main(args=sys.argv[1:]):  # noqa  pragma: no cover
    """Parse the args, run the commands."""

    handler = ArgumentHandler()

    # "Top-level" arguments, these will get passed around as part of
    # the global context
    handler.add_argument('-l',
                         '--log_level',
                         default='warn',
                         help="Logging level (debug, info, warn, error, critical)")

    handler.add_argument('-p',
                         '--profile',
                         dest='profile_name',
                         default=None)

    handler.add_argument('-n',
                         '--network',
                         dest='network_name',
                         default=None)

    handler.add_argument('-o',
                         '--output_format',
                         default='dkvp',
                         choices=FORMATS.keys())

    handler.add_argument(
        '-t',
        '--timeout',
        default=30,
        type=int,
        help="maximum time (in seconds) for the command to complete")

    # As it stands the @subcmd decorator doesn't quite do the right
    # thing for nested subcommands, so manually set up the subcommands
    # here (and in the nested subs as well).
    handler.set_subcommands({
        'build': build,
        'call': call,
        'config': config,
        'flash': flash,
        'help': help,
        'node': node,
        'mesh': mesh,
        'send': send,
        'update': update,
        'version': version,
        'autocomplete': autocomplete_path
    })

    def ctx(context):
        """Do initial setup"""

        config_logging(context.log_level)

        log.debug("Context: %r", context)
        log.info("Profile is %s", context.profile_name)

        init_configuration(context)

        def mk_gus():
            """Create a new Gus from the context"""
            return snapstraction.gus.Gus(context.profile, context.network, context.license)

        context.gus = mk_gus

        # Set up the output
        config_output(context)

        return context

    log_command(sys.argv)
    handler.run(args, context_fxn=ctx)


if __name__ == "__main__":
    main()

==> snapbelt-0.13.0-py2-none-any.whl: snapbelt/main.py <==
"""SNAPtoolbelt Main"""
import logging

import signal
import tornado.ioloop

import os
import sys

from arghandler import ArgumentHandler

from colorlog import ColoredFormatter

from snap_profile.profile import Profile, SerialProfile
from snap_profile.network import Network

import snapstraction.gus

import time

from .command_log import log_command

# Import subcommands
from .build import build
from .configure import config
from .flash import flash
from .help import help
from .node import node
from .mesh import mesh
from .low_level import call, send
from .updater import update
from .util import mkdir_p
from .output_formatters import FORMATS

log = logging.getLogger(__name__)

MAX_WAIT_SECONDS_BEFORE_SHUTDOWN = 2


def setup_sighandlers():  # pragma: no cover
    def sig_handler(sig, frame):  # pragma: no cover
        log.info('Caught signal: %s', sig)
        tornado.ioloop.IOLoop.instance().add_callback(shutdown)

    def shutdown():  # pragma: no cover
        log.info('Stopping IOLoop')

        log.info('Will shutdown in %s seconds ...',
                 MAX_WAIT_SECONDS_BEFORE_SHUTDOWN)
        io_loop = tornado.ioloop.IOLoop.instance()

        deadline = time.time() + MAX_WAIT_SECONDS_BEFORE_SHUTDOWN

        def stop_loop():  # pragma: no cover
            now = time.time()
            if now < deadline and (io_loop._callbacks or io_loop._timeouts):
                io_loop.add_timeout(now + 1, stop_loop)
            else:
                io_loop.stop()
                log.info('Shutdown')

        stop_loop()

    signal.signal(signal.SIGTERM, sig_handler)
    signal.signal(signal.SIGINT, sig_handler)

# Go ahead and register handlers
setup_sighandlers()


def parse_log_level(level_str):
    """Parse a log level string into the logging.* log level. """
    loglevel = getattr(logging, level_str.upper(), None)
    if not isinstance(loglevel, int):
        raise ValueError('Invalid log level: %s' % level_str)

    return loglevel


def config_logging(level_str):
    """Set up colorized logging"""

    level = parse_log_level(level_str)

    formatter = ColoredFormatter(
        "%(asctime)-15s %(log_color)s%(levelname)-8s%(reset)s %(name)-8s %(blue)s%(message)s",
        datefmt=None,
        reset=True,
        log_colors={
            'DEBUG': 'cyan',
            'INFO': 'green',
            'WARNING': 'yellow',
            'ERROR': 'red',
            'CRITICAL': 'red'
        })

    handler = logging.StreamHandler()
    handler.setFormatter(formatter)
    handler.setLevel(level)

    root_logger = logging.getLogger('')
    root_logger.setLevel(level)

    # Remove any extraneous handlers
    map(root_logger.removeHandler, root_logger.handlers)

    root_logger.addHandler(handler)


def config_output(context):
    """Set up the context's output formatter"""
    context.output = FORMATS[context.output_format]()


def _get_profile(context):
    """Load the profile.
    # If there was no profile specified:
    #    Fall back on the default.
    #    If the fallback doesn't exist, create & save it.
    # If there was a profile specified:
    #    If it exists, use it.
    #    If it doesn't exist, ERROR.
    """

    if context.profile_name is None:
        # There was no profile specified.
        # Fall back on the default.
        context.profile_name = 'default'

        try:
            context.profile = Profile.load(context.profile_name)
        except:
            # If the default doesn't exist, create it.
            profile = SerialProfile()
            # Save the default for future expansion
            profile.save()
            context.profile = profile

    else:
        # A profile was specified.
        try:
            context.profile = Profile.load(context.profile_name)
        except:
            log.error("Could not find profile %s", context.profile_name)
            exit(1)


def _get_network(context):
    """Load the network.
    # If there was no network specified:
    #     Fall back on the default *for the current profile*.
    #     If the fallback network doesn't exist, create it.
    # If there was a network specified:
    #    If it exists, great, use it.
    #    If it doesn't exist, ERROR.
    """
    if context.network_name is None:
        log.debug(
            "No network specified, using last known network for profile.")
        context.network_name = context.profile.network

        try:
            context.network = Network.load(context.network_name)

            # Update the last used profile
            context.profile.network = context.network.name
            context.profile.save()

        except:
            # Network not specified, and couldn't be found, create a default.
            log.debug(
                "Unable to load network, falling back on factory default")
            # fall back on default
            net = Network()
            # Name it correctly.
            net.name = context.network_name
            # Save the default for future expansion
            net.save()
            context.network = net

    else:
        # A network was explicitly specified
        try:
            context.network = Network.load(context.network_name)

            # Update the last used profile
            context.profile.network = context.network.name
            context.profile.save()

        except:
            log.error("Could not find network %s", context.network_name)
            exit(1)


def init_configuration(context):
    """Initialize the configuration folder"""
    # If there's not already a ~/.snap folder, create it.
    # TODO: Does this need to be elsewhere on Windows?
    user_dir = os.path.expanduser(os.path.join("~", ".snap"))
    try:
        log.info("Creating User Dir %s if it doesn't already exist", user_dir)
        mkdir_p(user_dir)
    except:
        log.exception(
            "Couldn't create user folder %s, you don't own your own home folder?!",
            user_dir)
        exit(1)

    _get_profile(context)
    # At this point, we've either errored out, or we have a profile.
    _get_network(context)

    context.license = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                                   'License.dat')


def version(parser, context, args):
    """Print the version and exit"""
    from ._version import __version__
    context.output({'version': __version__})
    exit(0)


def autocomplete_path(parser, context, args):
    """Emit the path to the autocomplete script for use with eval $(snap autocomplete)"""
    context.output(os.path.abspath(os.path.join(os.path.dirname(__file__),
                                                'bash_autocomplete_snap')))
    exit(0)


def main(args=sys.argv[1:]):  # noqa  pragma: no cover
    """Parse the args, run the commands."""

    handler = ArgumentHandler()

    # "Top-level" arguments, these will get passed around as part of
    # the global context
    handler.add_argument(
        '-l',
        '--log_level',
        default='warn',
        help="Logging level (debug, info, warn, error, critical)")

    handler.add_argument('-p', '--profile', dest='profile_name', default=None)

    handler.add_argument('-n', '--network', dest='network_name', default=None)

    handler.add_argument('-o',
                         '--output_format',
                         default='dkvp',
                         choices=FORMATS.keys())

    handler.add_argument(
        '-t',
        '--timeout',
        default=30,
        type=int,
        help="maximum time (in seconds) for the command to complete")

    # As it stands the @subcmd decorator doesn't quite do the right
    # thing for nested subcommands, so manually set up the subcommands
    # here (and in the nested subs as well).
    handler.set_subcommands({
        'build': build,
        'call': call,
        'config': config,
        'flash': flash,
        'help': help,
        'node': node,
        'mesh': mesh,
        'send': send,
        'update': update,
        'version': version,
        'autocomplete': autocomplete_path
    })

    def ctx(context):
        """Do initial setup"""

        config_logging(context.log_level)

        log.debug("Context: %r", context)
        log.info("Profile is %s", context.profile_name)

        init_configuration(context)

        def mk_gus():
            """Create a new Gus from the context"""
            return snapstraction.gus.Gus(context.profile, context.network,
                                         context.license)

        context.gus = mk_gus

        # Set up the output
        config_output(context)

        return context

    log_command(sys.argv)
    handler.run(args, context_fxn=ctx)


if __name__ == "__main__":
    main()
